@@ -3,20 +3,21 @@
  *
  * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) version 3, or any
+ * later version accepted by the membership of KDE e.V. (or its
+ * successor approved by the membership of KDE e.V.), which shall
+ * act as a proxy defined in Section 6 of version 3 of the license.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * GNU Lesser General Public License for more details.
  *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "authjob.h"
@@ -65,7 +66,7 @@ class Q_DECL_HIDDEN AuthJob::Private
 };
 
 AuthJob::Private::Private(AuthJob *parent):
-    widget(0),
+    widget(nullptr),
     q(parent)
 {
 }
@@ -129,7 +130,7 @@ void AuthJob::Private::_k_destructDelayed()
     if (dialog->isVisible())
         dialog->hide();
     dialog->deleteLater();
-    dialog = 0;
+    dialog = nullptr;
 }
 
 
@@ -208,7 +209,7 @@ void AuthJob::dispatchRequest(QNetworkAccessManager* accessManager, const QNetwo
 
 void AuthJob::start()
 {
-    AuthWidget *widget = 0;
+    AuthWidget *widget = nullptr;
 
     if (d->account->refreshToken().isEmpty() || (d->account->m_scopesChanged == true)) {
 
@@ -251,6 +252,7 @@ void AuthJob::start()
                 this, SLOT(_k_destructDelayed()));
         connect(widget, SIGNAL(error(KGAPI2::Error,QString)),
                 this, SLOT(_k_destructDelayed()));
+        connect(buttons, &QDialogButtonBox::rejected, this, &AuthJob::emitFinished);
 
         d->dialog->show();
         widget->authenticate();
