@@ -1,14 +1,25 @@
 /*
-    SPDX-FileCopyrightText: 2012 Andrius da Costa Ribas <andriusmao@gmail.com>
+    Copyright 2012  Andrius da Costa Ribas <andriusmao@gmail.com>
 
-    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) version 3, or any
+    later version accepted by the membership of KDE e.V. (or its
+    successor approved by the membership of KDE e.V.), which shall
+    act as a proxy defined in Section 6 of version 3 of the license.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU Lesser General Public License for more details.
+
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include "about.h"
-#include "debug.h"
 #include "user.h"
-#include "utils.h"
-#include "utils_p.h"
 
 #include <QJsonDocument>
 
@@ -19,7 +30,7 @@ using namespace KGAPI2::Drive;
 
 class Q_DECL_HIDDEN About::Format::Private
 {
-public:
+  public:
     Private();
     Private(const Private &other);
 
@@ -31,19 +42,19 @@ About::Format::Private::Private()
 {
 }
 
-About::Format::Private::Private(const Private &other)
-    : source(other.source)
-    , targets(other.targets)
+About::Format::Private::Private(const Private &other):
+    source(other.source),
+    targets(other.targets)
 {
 }
 
-About::Format::Format()
-    : d(new Private)
+About::Format::Format():
+    d(new Private)
 {
 }
 
-About::Format::Format(const About::Format &other)
-    : d(new Private(*(other.d)))
+About::Format::Format(const About::Format &other):
+    d(new Private(*(other.d)))
 {
 }
 
@@ -52,13 +63,6 @@ About::Format::~Format()
     delete d;
 }
 
-bool About::Format::operator==(const About::Format &other) const
-{
-    GAPI_COMPARE(source)
-    GAPI_COMPARE(targets)
-    return true;
-}
-
 QString About::Format::source() const
 {
     return d->source;
@@ -73,7 +77,7 @@ QStringList About::Format::targets() const
 
 class Q_DECL_HIDDEN About::AdditionalRoleInfo::RoleSet::Private
 {
-public:
+  public:
     Private();
     Private(const Private &other);
 
@@ -85,19 +89,19 @@ About::AdditionalRoleInfo::RoleSet::Private::Private()
 {
 }
 
-About::AdditionalRoleInfo::RoleSet::Private::Private(const Private &other)
-    : primaryRole(other.primaryRole)
-    , additionalRoles(other.additionalRoles)
+About::AdditionalRoleInfo::RoleSet::Private::Private(const Private &other):
+    primaryRole(other.primaryRole),
+    additionalRoles(other.additionalRoles)
 {
 }
 
-About::AdditionalRoleInfo::RoleSet::RoleSet()
-    : d(new Private)
+About::AdditionalRoleInfo::RoleSet::RoleSet():
+    d(new Private)
 {
 }
 
-About::AdditionalRoleInfo::RoleSet::RoleSet(const About::AdditionalRoleInfo::RoleSet &other)
-    : d(new Private(*(other.d)))
+About::AdditionalRoleInfo::RoleSet::RoleSet(const About::AdditionalRoleInfo::RoleSet &other):
+    d(new Private(*(other.d)))
 {
 }
 
@@ -106,13 +110,6 @@ About::AdditionalRoleInfo::RoleSet::~RoleSet()
     delete d;
 }
 
-bool About::AdditionalRoleInfo::RoleSet::operator==(const RoleSet &other) const
-{
-    GAPI_COMPARE(primaryRole)
-    GAPI_COMPARE(additionalRoles)
-    return true;
-}
-
 QString About::AdditionalRoleInfo::RoleSet::primaryRole() const
 {
     return d->primaryRole;
@@ -127,7 +124,7 @@ QStringList About::AdditionalRoleInfo::RoleSet::additionalRoles() const
 
 class Q_DECL_HIDDEN About::AdditionalRoleInfo::Private
 {
-public:
+  public:
     Private();
     Private(const Private &other);
 
@@ -139,19 +136,19 @@ About::AdditionalRoleInfo::Private::Private()
 {
 }
 
-About::AdditionalRoleInfo::Private::Private(const Private &other)
-    : type(other.type)
-    , roleSets(other.roleSets)
+About::AdditionalRoleInfo::Private::Private(const Private &other):
+    type(other.type),
+    roleSets(other.roleSets)
 {
 }
 
-About::AdditionalRoleInfo::AdditionalRoleInfo()
-    : d(new Private)
+About::AdditionalRoleInfo::AdditionalRoleInfo():
+    d(new Private)
 {
 }
 
-About::AdditionalRoleInfo::AdditionalRoleInfo(const About::AdditionalRoleInfo &other)
-    : d(new Private(*(other.d)))
+About::AdditionalRoleInfo::AdditionalRoleInfo(const About::AdditionalRoleInfo &other):
+    d(new Private(*(other.d)))
 {
 }
 
@@ -160,13 +157,6 @@ About::AdditionalRoleInfo::~AdditionalRoleInfo()
     delete d;
 }
 
-bool About::AdditionalRoleInfo::operator==(const AdditionalRoleInfo &other) const
-{
-    GAPI_COMPARE(type)
-    GAPI_COMPARE_CONTAINERS(roleSets)
-    return true;
-}
-
 QString About::AdditionalRoleInfo::type() const
 {
     return d->type;
@@ -181,7 +171,7 @@ About::AdditionalRoleInfo::RoleSetsList About::AdditionalRoleInfo::roleSets() co
 
 class Q_DECL_HIDDEN About::Feature::Private
 {
-public:
+  public:
     Private();
     Private(const Private &other);
 
@@ -189,24 +179,24 @@ public:
     qreal featureRate;
 };
 
-About::Feature::Private::Private()
-    : featureRate(-1)
+About::Feature::Private::Private():
+    featureRate(-1)
 {
 }
 
-About::Feature::Private::Private(const Private &other)
-    : featureName(other.featureName)
-    , featureRate(other.featureRate)
+About::Feature::Private::Private(const Private &other):
+    featureName(other.featureName),
+    featureRate(other.featureRate)
 {
 }
 
-About::Feature::Feature()
-    : d(new Private)
+About::Feature::Feature():
+    d(new Private)
 {
 }
 
-About::Feature::Feature(const About::Feature &other)
-    : d(new Private(*(other.d)))
+About::Feature::Feature(const About::Feature &other):
+    d(new Private(*(other.d)))
 {
 }
 
@@ -215,13 +205,6 @@ About::Feature::~Feature()
     delete d;
 }
 
-bool About::Feature::operator==(const Feature &other) const
-{
-    GAPI_COMPARE(featureName)
-    GAPI_COMPARE(featureRate)
-    return true;
-}
-
 QString About::Feature::featureName() const
 {
     return d->featureName;
@@ -236,7 +219,7 @@ qreal About::Feature::featureRate() const
 
 class Q_DECL_HIDDEN About::MaxUploadSize::Private
 {
-public:
+  public:
     Private();
     Private(const Private &other);
 
@@ -244,39 +227,31 @@ public:
     qlonglong size;
 };
 
-About::MaxUploadSize::Private::Private()
-    : size(-1)
+About::MaxUploadSize::Private::Private():
+    size(-1)
 {
 }
 
-About::MaxUploadSize::Private::Private(const Private &other)
-    : type(other.type)
-    , size(other.size)
+About::MaxUploadSize::Private::Private(const Private &other):
+    type(other.type),
+    size(other.size)
 {
 }
 
-About::MaxUploadSize::MaxUploadSize()
-    : d(new Private)
+About::MaxUploadSize::MaxUploadSize():
+    d(new Private)
 {
 }
 
-About::MaxUploadSize::MaxUploadSize(const About::MaxUploadSize &other)
-    : d(new Private(*(other.d)))
-{
-}
+About::MaxUploadSize::MaxUploadSize(const About::MaxUploadSize &other):
+    d(new Private(*(other.d)))
+{ }
 
 About::MaxUploadSize::~MaxUploadSize()
 {
     delete d;
 }
 
-bool About::MaxUploadSize::operator==(const MaxUploadSize &other) const
-{
-    GAPI_COMPARE(type)
-    GAPI_COMPARE(size)
-    return true;
-}
-
 QString About::MaxUploadSize::type() const
 {
     return d->type;
@@ -291,7 +266,7 @@ qlonglong About::MaxUploadSize::size() const
 
 class Q_DECL_HIDDEN About::Private
 {
-public:
+  public:
     Private();
     Private(const Private &other);
 
@@ -312,131 +287,57 @@ public:
     MaxUploadSizesList maxUploadSizes;
     QString permissionId;
     bool isCurrentAppInstalled;
-    bool canCreateDrives;
     UserPtr user;
 };
 
-About::Private::Private()
-    : quotaBytesTotal(-1)
-    , quotaBytesUsed(-1)
-    , quotaBytesUsedInTrash(-1)
-    , quotaBytesUsedAggregate(-1)
-    , largestChangeId(-1)
-    , remainingChangeIds(-1)
-    , isCurrentAppInstalled(false)
-    , canCreateDrives(false)
+About::Private::Private():
+    quotaBytesTotal(-1),
+    quotaBytesUsed(-1),
+    quotaBytesUsedInTrash(-1),
+    quotaBytesUsedAggregate(-1),
+    largestChangeId(-1),
+    remainingChangeIds(-1),
+    isCurrentAppInstalled(false)
 {
 }
 
-About::Private::Private(const About::Private &other)
-    : selfLink(other.selfLink)
-    , name(other.name)
-    , quotaBytesTotal(other.quotaBytesTotal)
-    , quotaBytesUsed(other.quotaBytesUsed)
-    , quotaBytesUsedInTrash(other.quotaBytesUsedInTrash)
-    , quotaBytesUsedAggregate(other.quotaBytesUsedAggregate)
-    , largestChangeId(other.largestChangeId)
-    , remainingChangeIds(other.remainingChangeIds)
-    , rootFolderId(other.rootFolderId)
-    , domainSharingPolicy(other.domainSharingPolicy)
-    , importFormats(other.importFormats)
-    , exportFormats(other.exportFormats)
-    , additionalRoleInfo(other.additionalRoleInfo)
-    , features(other.features)
-    , maxUploadSizes(other.maxUploadSizes)
-    , permissionId(other.permissionId)
-    , isCurrentAppInstalled(other.isCurrentAppInstalled)
-    , canCreateDrives(other.canCreateDrives)
-    , user(other.user)
+About::Private::Private(const About::Private &other):
+    selfLink(other.selfLink),
+    name(other.name),
+    quotaBytesTotal(other.quotaBytesTotal),
+    quotaBytesUsed(other.quotaBytesUsed),
+    quotaBytesUsedInTrash(other.quotaBytesUsedInTrash),
+    quotaBytesUsedAggregate(other.quotaBytesUsedAggregate),
+    largestChangeId(other.largestChangeId),
+    remainingChangeIds(other.remainingChangeIds),
+    rootFolderId(other.rootFolderId),
+    domainSharingPolicy(other.domainSharingPolicy),
+    importFormats(other.importFormats),
+    exportFormats(other.exportFormats),
+    additionalRoleInfo(other.additionalRoleInfo),
+    features(other.features),
+    maxUploadSizes(other.maxUploadSizes),
+    permissionId(other.permissionId),
+    isCurrentAppInstalled(other.isCurrentAppInstalled),
+    user(other.user)
 {
 }
 
-const QString About::Fields::AdditionalRoleInfo = QStringLiteral("additionalRoleInfo");
-const QString About::Fields::AdditionalRoles = QStringLiteral("additionalRoles");
-const QString About::Fields::BackgroundImageLink = QStringLiteral("backgroundImageLink");
-const QString About::Fields::BytesUsed = QStringLiteral("bytesUsed");
-const QString About::Fields::CanCreateDrives = QStringLiteral("canCreateDrives");
-const QString About::Fields::ColorRgb = QStringLiteral("colorRgb");
-const QString About::Fields::DisplayName = QStringLiteral("displayName");
-const QString About::Fields::DomainSharingPolicy = QStringLiteral("domainSharingPolicy");
-const QString About::Fields::EmailAddress = QStringLiteral("emailAddress");
-const QString About::Fields::Etag = QStringLiteral("etag");
-const QString About::Fields::ExportFormats = QStringLiteral("exportFormats");
-const QString About::Fields::FeatureName = QStringLiteral("featureName");
-const QString About::Fields::FeatureRate = QStringLiteral("featureRate");
-const QString About::Fields::Features = QStringLiteral("features");
-const QString About::Fields::FolderColorPalette = QStringLiteral("folderColorPalette");
-const QString About::Fields::Id = QStringLiteral("id");
-const QString About::Fields::ImportFormats = QStringLiteral("importFormats");
-const QString About::Fields::IsAuthenticatedUser = QStringLiteral("isAuthenticatedUser");
-const QString About::Fields::IsCurrentAppInstalled = QStringLiteral("isCurrentAppInstalled");
-const QString About::Fields::Kind = QStringLiteral("kind");
-const QString About::Fields::LanguageCode = QStringLiteral("languageCode");
-const QString About::Fields::LargestChangeId = QStringLiteral("largestChangeId");
-const QString About::Fields::MaxUploadSizes = QStringLiteral("maxUploadSizes");
-const QString About::Fields::Name = QStringLiteral("name");
-const QString About::Fields::PermissionId = QStringLiteral("permissionId");
-const QString About::Fields::Picture = QStringLiteral("picture");
-const QString About::Fields::PrimaryRole = QStringLiteral("primaryRole");
-const QString About::Fields::QuotaBytesByService = QStringLiteral("quotaBytesByService");
-const QString About::Fields::QuotaBytesTotal = QStringLiteral("quotaBytesTotal");
-const QString About::Fields::QuotaBytesUsedAggregate = QStringLiteral("quotaBytesUsedAggregate");
-const QString About::Fields::QuotaBytesUsedInTrash = QStringLiteral("quotaBytesUsedInTrash");
-const QString About::Fields::QuotaBytesUsed = QStringLiteral("quotaBytesUsed");
-const QString About::Fields::QuotaType = QStringLiteral("quotaType");
-const QString About::Fields::RemainingChangeIds = QStringLiteral("remainingChangeIds");
-const QString About::Fields::RoleSets = QStringLiteral("roleSets");
-const QString About::Fields::RootFolderId = QStringLiteral("rootFolderId");
-const QString About::Fields::SelfLink = QStringLiteral("selfLink");
-const QString About::Fields::ServiceName = QStringLiteral("serviceName");
-const QString About::Fields::Size = QStringLiteral("size");
-const QString About::Fields::Source = QStringLiteral("source");
-const QString About::Fields::Targets = QStringLiteral("targets");
-const QString About::Fields::TeamDriveThemes = QStringLiteral("teamDriveThemes");
-const QString About::Fields::Type = QStringLiteral("type");
-const QString About::Fields::Url = QStringLiteral("url");
-const QString About::Fields::User = QStringLiteral("user");
-
-About::About()
-    : KGAPI2::Object()
-    , d(new Private)
+About::About():
+    KGAPI2::Object(),
+    d(new Private)
 {
 }
 
-About::About(const About &other)
-    : KGAPI2::Object(other)
-    , d(new Private(*(other.d)))
+About::About(const About &other):
+    KGAPI2::Object(other),
+    d(new Private(*(other.d)))
 {
 }
 
-About::~About() = default;
-
-bool About::operator==(const About &other) const
+About::~About()
 {
-    if (!Object::operator==(other)) {
-        return false;
-    }
-
-    GAPI_COMPARE(selfLink)
-    GAPI_COMPARE(name)
-    GAPI_COMPARE(quotaBytesTotal)
-    GAPI_COMPARE(quotaBytesUsed)
-    GAPI_COMPARE(quotaBytesUsedInTrash)
-    GAPI_COMPARE(quotaBytesUsedInTrash)
-    GAPI_COMPARE(largestChangeId)
-    GAPI_COMPARE(remainingChangeIds)
-    GAPI_COMPARE(rootFolderId)
-    GAPI_COMPARE(domainSharingPolicy)
-    GAPI_COMPARE_CONTAINERS(importFormats)
-    GAPI_COMPARE_CONTAINERS(exportFormats)
-    GAPI_COMPARE_CONTAINERS(additionalRoleInfo)
-    GAPI_COMPARE_CONTAINERS(features)
-    GAPI_COMPARE_CONTAINERS(maxUploadSizes)
-    GAPI_COMPARE(permissionId)
-    GAPI_COMPARE(isCurrentAppInstalled)
-    GAPI_COMPARE(canCreateDrives)
-    GAPI_COMPARE_SHAREDPTRS(user)
-    return true;
+    delete d;
 }
 
 QUrl About::selfLink() const
@@ -535,11 +436,6 @@ UserPtr About::user() const
     return d->user;
 }
 
-bool About::canCreateDrives() const
-{
-    return d->canCreateDrives;
-}
-
 AboutPtr About::fromJSON(const QByteArray &jsonData)
 {
     QJsonDocument document = QJsonDocument::fromJson(jsonData);
@@ -548,7 +444,9 @@ AboutPtr About::fromJSON(const QByteArray &jsonData)
     }
     const QVariantMap map = document.toVariant().toMap();
 
-    if (!map.contains(QLatin1String("kind")) || map[QStringLiteral("kind")].toString() != QLatin1String("drive#about")) {
+    if (!map.contains(QStringLiteral("kind")) ||
+        map[QStringLiteral("kind")].toString() != QLatin1String("drive#about")) {
+
         return AboutPtr();
     }
 
@@ -566,10 +464,9 @@ AboutPtr About::fromJSON(const QByteArray &jsonData)
     about->d->domainSharingPolicy = map.value(QStringLiteral("domainSharingPolicy")).toString();
     about->d->permissionId = map.value(QStringLiteral("permissionId")).toString();
     about->d->isCurrentAppInstalled = map.value(QStringLiteral("isCurrentAppInstalled")).toBool();
-    about->d->canCreateDrives = map.value(QStringLiteral("canCreateDrives")).toBool();
 
     const QVariantList importFormats = map.value(QStringLiteral("importFormats")).toList();
-    for (const QVariant &v : importFormats) {
+    Q_FOREACH (const QVariant &v, importFormats) {
         const QVariantMap importFormat = v.toMap();
         FormatPtr format(new Format());
         format->d->source = importFormat.value(QStringLiteral("source")).toString();
@@ -579,7 +476,7 @@ AboutPtr About::fromJSON(const QByteArray &jsonData)
     }
 
     const QVariantList exportFormats = map.value(QStringLiteral("exportFormats")).toList();
-    for (const QVariant &v : exportFormats) {
+    Q_FOREACH (const QVariant &v, exportFormats) {
         const QVariantMap exportFormat = v.toMap();
         FormatPtr format(new Format());
         format->d->source = exportFormat.value(QStringLiteral("source")).toString();
@@ -589,13 +486,13 @@ AboutPtr About::fromJSON(const QByteArray &jsonData)
     }
 
     const QVariantList additionalRoleInfos = map.value(QStringLiteral("additionalRoleInfo")).toList();
-    for (const QVariant &v : additionalRoleInfos) {
+    Q_FOREACH (const QVariant &v, additionalRoleInfos) {
         const QVariantMap additionalRoleInfo = v.toMap();
         AdditionalRoleInfoPtr info(new AdditionalRoleInfo());
         info->d->type = additionalRoleInfo.value(QStringLiteral("type")).toString();
 
         const QVariantList roleSets = additionalRoleInfo.value(QStringLiteral("roleSets")).toList();
-        for (const QVariant &vv : roleSets) {
+        Q_FOREACH (const QVariant &vv, roleSets) {
             const QVariantMap roleSetData = vv.toMap();
             AdditionalRoleInfo::RoleSetPtr roleSet(new AdditionalRoleInfo::RoleSet());
             roleSet->d->primaryRole = roleSetData.value(QStringLiteral("primaryRole")).toString();
@@ -608,7 +505,7 @@ AboutPtr About::fromJSON(const QByteArray &jsonData)
     }
 
     const QVariantList features = map.value(QStringLiteral("features")).toList();
-    for (const QVariant &v : features) {
+    Q_FOREACH (const QVariant &v, features) {
         const QVariantMap featureData = v.toMap();
         FeaturePtr feature(new Feature());
         feature->d->featureName = featureData.value(QStringLiteral("featureName")).toString();
@@ -618,7 +515,7 @@ AboutPtr About::fromJSON(const QByteArray &jsonData)
     }
 
     const QVariantList maxUploadSizes = map.value(QStringLiteral("maxUploadSizes")).toList();
-    for (const QVariant &v : maxUploadSizes) {
+    Q_FOREACH (const QVariant &v, maxUploadSizes) {
         const QVariantMap maxUploadSizeData = v.toMap();
         MaxUploadSizePtr maxUploadSize(new MaxUploadSize());
         maxUploadSize->d->type = maxUploadSizeData.value(QStringLiteral("type")).toString();
